pub struct OnDemandRelation {
pub relation: RelationRow,
pub attributes: &'static [AttributeRow],
pub indexes: &'static [IndexRow],
pub free_list: u32,
}Expand description
A relation macOS does not put in a new keychain, but adds to the schema the
first time a record of that type is stored. security import writes exactly
these rows, in this order, when it stores the first certificate.
Fields
relation: RelationRowattributes: &'static [AttributeRow]indexes: &'static [IndexRow]free_list: u32The free-list field of the new, still-empty table.