pub struct Tlv {
pub tag: u8,
pub start: usize,
pub end: usize,
pub next: usize,
}Expand description
A tag-length-value element, with its contents located inside the input.
Fields
tag: u8start: usizeOffset of the first content byte.
end: usizeOffset one past the last content byte.
next: usizeOffset one past the whole element, header included.
Implementations
Sourceimpl Tlv
impl Tlv
pub fn contents<'a>(&self, data: &'a [u8]) -> &'a [u8] ⓘ
Sourcepub fn element<'a>(&self, data: &'a [u8], header_start: usize) -> &'a [u8] ⓘ
pub fn element<'a>(&self, data: &'a [u8], header_start: usize) -> &'a [u8] ⓘ
The element including its tag and length, which is what the keychain stores for a name.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool