pub fn for_application(path: &Path) -> Result<TrustedApplication>Expand description
Without the trust-apps feature there is no way to read a signature.
pub fn for_application(path: &Path) -> Result<TrustedApplication>Without the trust-apps feature there is no way to read a signature.