pub fn expected_format(name: &str) -> AttributeFormatExpand description
Formats used by the password relations, for tests and diagnostics.
pub fn expected_format(name: &str) -> AttributeFormatFormats used by the password relations, for tests and diagnostics.